import { View, Button, Text, RadioGroup, Picker, Image, Input, Radio, Label, ScrollView, Slot } from '@tarojs/components'
import Taro, { useDidShow, useRouter } from '@tarojs/taro';
import { useState } from 'react';
import Form from '@/components/Form';
import FormItem from '@/components/Form/FormItem';
import AuthProfile from '@/components/Authorize/AuthProfile';
import { addDogList, addlication, getDogInfo } from '@/services/dogAPI';
import { handleFile } from '@/utils/request';
import { useModel } from '@/store';

import './style.less'

export default (props) => {
  const { dogs, person } = useModel('userData')
  const [formData, setFormData] = useState()

  const [dogDate, setDogDate] = useState({ immunizationDate: null, petBirthday: '请选择生日', petSex: [], petType: [] })
  const [mainDog, setMainDog] = useState([])

  const router = useRouter()
  const applyType = router.params.type || 'first'

  useDidShow(() => {
    addDogList().then((res) => {
      setMainDog(res.records)
    })
  }, [])

  const getMainDogChange = (value) => {
    console.log("🚀 ~ file: index.jsx ~ line 34 ~ getMainDogChange ~ value", value)
    const { petId } = value.detail.data

    getDogInfo(petId).then((e) => {
      setFormData(e)
      const sex = [{ value: e?.sex, text: e?.sex == 1 ? '雄' : '雌' }];
      const petType = [{ value: 0, name: e?.petType }];

      setDogDate({ ...dogDate, petBirthday: e?.birthday, petSex: sex, petType: petType })
      console.log('test', e);

    })
  }

  const onDateChange = (type, value) => {
    console.log('dogDate', dogDate);

    switch (type) {
      case 'petSex':
        setDogDate({ ...dogDate, petSex: value })
        break;
      case 'petBirthday':
        setDogDate({ ...dogDate, petBirthday: value })
        break;
      case 'petType':
        setDogDate({ ...dogDate, petType: value })
        break;
      case 'immunizationDate':
        setDogDate({ ...dogDate, immunizationDate: value })
        break;
      default:
        break;
    }
  }

  const modeList = [
    {
      value: 1,
      text: '邮寄',
    },
    {
      value: 2,
      text: '自取',
    },
  ]

  // ...dogDate,
  const formSubmit = value => {
    addlication({ ...value, applyType }).then((res) => {
      console.log('dogInfo xinwe', res);
      Taro.showToast({
        title: '保存成功',
        icon: 'none',
        duration: 1000
      })
      Taro.reLaunch({
        url: `/pages/payPage/index?id=${res.applyId}`
      })
    })
  }



  return (
    <ScrollView scrollY style={{ height: '100vh' }} >
      <AuthProfile />
      <View class='page' >
        <Form onSubmit={formSubmit} >
          <mp-form  >
            <mp-cells >
              <FormItem title='犬主姓名' required>
                <View >{person?.nickName}</View>
              </FormItem>
              <FormItem title='狗狗名称' required>
                <s-picker name='petName' rangeKey='name' rangeValue='value' range={mainDog} value={formData?.name} onChange={getMainDogChange} />
              </FormItem>
              <FormItem title='狗狗性别' required>
                <s-picker name='petSex' rangeKey='text' rangeValue='value' range={dogDate.petSex} value={formData?.sex} />
              </FormItem>
              <FormItem title='犬种' required>
                <s-picker name='petType' rangeKey='name' rangeValue='name' range={dogDate.petType} value={formData?.petType} />
              </FormItem>
              <FormItem title='生日' required>
                <Picker name='petBirthday' mode='date' onChange={(e) => { onDateChange('petBirthday', e.detail.value) }}>
                  <View className='picker' style={!formData ? { "color": '#858585' } : {}}>
                    {dogDate.petBirthday}
                  </View>
                </Picker>
              </FormItem>
              <FormItem title='毛色' required>
                <Input name='petColor' placeholder='请输入毛色' value={formData?.color} />
              </FormItem>
              <FormItem title='狗狗照片' required>
                <uploader name='dogImg1' onFile={handleFile} value={formData?.image} />
              </FormItem>
              <FormItem title='最近免疫日期' required>
                <Picker name='immunizationDate' mode='date' onChange={(e) => { onDateChange('immunizationDate', e.detail.value) }}>
                  {dogDate?.immunizationDate ? (
                    <View className='picker' >
                      {dogDate.immunizationDate}
                    </View>
                  ) : <View style={{ color: '#858585' }}>请选择...</View>
                  }

                </Picker>
              </FormItem>
              <FormItem title='免疫证号' required>
                <Input name='immunizationCode' placeholder='请输入免疫证号' />
              </FormItem>
              <FormItem title='免疫证明' required>
                <uploader name='immunizationImg' onFile={handleFile} />
              </FormItem>
              <FormItem title='详细地址' required>
                <Input name='address' placeholder='请输入详细地址' />
              </FormItem>
              <FormItem title='申领方式' extClass=''>
                <View className='radio-list'>
                  <RadioGroup name='applyMethod'>
                    {modeList.map((item, i) => {
                      return (
                        <Label className='radio-list__label' for={i} key={i}>
                          <Radio color='#FCD905' className='radio-list__radio' value={item.value} >{item.text}</Radio>
                        </Label>
                      )
                    })}
                  </RadioGroup>
                </View>
              </FormItem>

            </mp-cells>
          </mp-form>
          <View slot='button' style={{ margin: '4em 0 2em 0' }}>
            <Button style={{ backgroundColor: '#fbd804', borderRadius: '40px', color: '#000', border: '0px' }} class='weui-btn' type='primary' loading={false} formType='submit'>确定</Button>
          </View>
        </Form>
      </View>
    </ScrollView >
  )
}




